pub struct Target {
pub name: String,
pub image: Option<PathBuf>,
pub uefi: bool,
pub kernel: Option<PathBuf>,
pub kernel_args: Option<String>,
pub rootfs: PathBuf,
pub arch: String,
pub qemu_command: Option<String>,
pub command: String,
pub vm: VMConfig,
}Expand description
Config for a single target
Fields
name: StringName of the testing target.
image: Option<PathBuf>Path to image to test against.
- The path is relative to
vmtest.toml. - The image must be bootable.
uefi: boolWhether or not image should be booted using UEFI
Default: false
kernel: Option<PathBuf>Path to kernel image to test against.
- The path is relative to
vmtest.toml. vmlinux,vmlinuz, andbzImageformats are accepted.
kernel_args: Option<String>Additional kernel command line parameters.
Arguments are only valid for kernel targets.
rootfs: PathBufPath to rootfs to test against.
- The path is relative to
vmtest.toml. - If not specified, the host’s rootfs will be used.
Default: /
arch: StringArch to run
qemu_command: Option<String>Command used to launch QEMU
command: StringCommand to run inside virtual machine.
vm: VMConfigVM Configuration.
Implementations
Sourceimpl Target
impl Target
Sourcepub fn default_rootfs() -> PathBuf
pub fn default_rootfs() -> PathBuf
Default rootfs path to use if none are specified.
Sourcepub fn default_arch() -> String
pub fn default_arch() -> String
Default architecure to use if none are specified.